pydevDAG._print._helpers module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._print package »

# pydevDAG._print._helpers module

## pydevDAG._print._helpers

Little snippets of code to print stuff.

class `pydevDAG._print._helpers.` `ByPath`

  Bases: `pydevDAG._print._helpers.NodeGetter`

  Get the value of the path devlink for the node.

  static `getter`(maps)
  `map_requires` = [u'DEVLINK']

class `pydevDAG._print._helpers.` `Devname`

  Bases: `pydevDAG._print._helpers.NodeGetter`

  Get a name for a node.

  static `getter`(maps)
  `map_requires` = [u'UDEV']

class `pydevDAG._print._helpers.` `Devpath`

  Bases: `pydevDAG._print._helpers.NodeGetter`

  Get a name for a node.

  static `getter`(maps)
  `map_requires` = [u'UDEV']

class `pydevDAG._print._helpers.` `Devtype`

  Bases: `pydevDAG._print._helpers.NodeGetter`

  Get a device type for a node.

  static `getter`(maps)
  `map_requires` = [u'UDEV']

class `pydevDAG._print._helpers.` `Diffstatus`

  Bases: `pydevDAG._print._helpers.NodeGetter`

  Get a diffstatus for a node.

  static `getter`(maps)
  `map_requires` = [u'diffstatus']

class `pydevDAG._print._helpers.` `Dmname`

  Bases: `pydevDAG._print._helpers.NodeGetter`

  Get a size for a node.

  static `getter`(maps)
  `map_requires` = [u'SYSFS']

class `pydevDAG._print._helpers.` `Identifier`

  Bases: `pydevDAG._print._helpers.NodeGetter`

  Get a name for a node.

  static `getter`(maps)
  `map_requires` = [u'identifier']

class `pydevDAG._print._helpers.` `NodeGetter`

  Bases: `object`

  Abstract parent class of classes for getting string info for a column.

  static `getter`(maps)

    Get a function that obtains a string from a node.

    Parameters: | maps (dict of str * (dict of node * object)) – a dict of maps from nodes to attribute values
    Returns: | a function that takes a node and returns a string
    Return type: | node -> (str or NoneType)

  `map_requires`

    A decorator indicating abstract properties.

    Requires that the metaclass is ABCMeta or derived from it. A class that has a metaclass derived from ABCMeta cannot be instantiated unless all of its abstract properties are overridden. The abstract properties can be called using any of the normal ‘super’ call mechanisms.

    Usage:

    > class C:

    >   __metaclass__ = ABCMeta @abstractproperty def my_abstract_property(self):

    >   > ...

    This defines a read-only property; you can also define a read-write abstract property using the ‘long’ form of property declaration:

    > class C:
    >   __metaclass__ = ABCMeta def getx(self): ... def setx(self, value): ... x = abstractproperty(getx, setx)

class `pydevDAG._print._helpers.` `NodeGetters`

  Bases: `object`

  Class for managing NodeGetters.

  `BY_PATH`

    alias of `ByPath`

  `DEVNAME`

    alias of `Devname`

  `DEVPATH`

    alias of `Devpath`

  `DEVTYPE`

    alias of `Devtype`

  `DIFFSTATUS`

    alias of `Diffstatus`

  `DMNAME`

    alias of `Dmname`

  `IDENTIFIER`

    alias of `Identifier`

  `SIZE`

    alias of `Size`

class `pydevDAG._print._helpers.` `Size`

  Bases: `pydevDAG._print._helpers.NodeGetter`

  Get a size for a node.

  static `getter`(maps)
  `map_requires` = [u'SYSFS']

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._print package »